"use client";
import { useState } from "react";
import DataTable from "@/components/tables/DataTable";
import { TableData } from "@/variables/columnsData";
import { DeleteIcon, ViewIcon } from "@chakra-ui/icons";
import { Flex, Button, Icon, useColorModeValue } from "@chakra-ui/react";
import useShowToast from "@/app/hooks/useShowToast";
import { useRouter } from "next/navigation";
import { hasPermission } from "@/utils/navigation";
import { useGeneral } from "@/contexts/GeneralContext";
import { columnsDataDc } from "../variables/columns";
import Filters from "@/components/filters/Filters";
import { extractPagination } from "@/utils/common";
import { MultiSelectOption } from "@/components/fields/MultiSelect";
import { deleteDc, getDcs } from "@/app/lib/dc/actions";

interface DcTableProps {
  data: { data: TableData[] };
  users: MultiSelectOption[];
  ibcs: MultiSelectOption[];
}

const DcTable: React.FC<DcTableProps> = ({ data, users, ibcs }) => {
  const { currentUser } = useGeneral();
  const brandColor = useColorModeValue("brand.500", "white");
  const router = useRouter();
  const showToast = useShowToast();
  const [loading, setLoading] = useState<number | null>(null);

  const paginationData = extractPagination(data);

  const handleView = async (id: number) => {
    router.push(`/admin/attempt/dc-form/view/${id}`);
  };

  const handleDelete = async (id: number) => {
    setLoading(id);
    try {
      const response = await deleteDc(id);
      if (response.status === false) {
        throw new Error(response.message || "Failed to delete dc.");
      }
      showToast("Dc Deleted!", response.message, "success");
      router.refresh();
    } catch (error: any) {
      showToast("Failed to delete", error.message, "error");
    } finally {
      setLoading(null);
    }
  };

  const actions = (id: number) => (
    <Flex gap={2}>
      {hasPermission(currentUser.permissions, "dc-form", "view") && (
        <Button
          variant="blank"
          alignItems="center"
          justifyContent="center"
          w="24px"
          h="24px"
          lineHeight="100%"
          borderRadius="10px"
          minW={0}
          onClick={() => {
            handleView(id);
          }}
          isDisabled={!hasPermission(currentUser.permissions, "dc-form", "view")}>
          <Icon as={ViewIcon} color={brandColor} w="20px" h="20px" />
        </Button>
      )}

      {hasPermission(currentUser.permissions, "dc-form", "delete") && (
        <Button
          variant="blank"
          alignItems="center"
          justifyContent="center"
          w="24px"
          h="24px"
          lineHeight="100%"
          borderRadius="10px"
          minW={0}
          onClick={() => {
            handleDelete(id);
          }}
          isDisabled={loading === id || !hasPermission(currentUser.permissions, "dc-form", "delete")}>
          <Icon as={DeleteIcon} color={brandColor} w="20px" h="20px" />
        </Button>
      )}
    </Flex>
  );

  return (
    <DataTable
      columnsData={columnsDataDc}
      tableData={data?.data as TableData[]}
      paginate={paginationData}
      isSelectable={false}
      showPageSize={false}
      showSearch={false}
      actionSlot={actions}
      filterSlot={
        <Filters onExport={getDcs} users={users} ibcs={ibcs} searchLabel="Contract Account" showBatches={false} />
      }
    />
  );
};

export default DcTable;
